@@ -3,6 +3,7 @@ package FlatLock;
 # Flat lock module written by Julian Lishev
 # This module is part of WebTools package!
 # Privacy and terms are same as WebTools!
+# www.proscriptum.com
 
 # This module can "lock" one or other number.
 # In that state it will stay till somebody
@@ -16,6 +17,7 @@ package FlatLock;
 # directory when you lock "fibre" and module
 # delete this file when fibre is unlocked!
 
+
 use strict;
 
 %FlatLock::AllMembers = ();
@@ -35,6 +37,14 @@ use strict;
 
 =cut
 
+BEGIN
+ {
+  use vars qw($VERSION @ISA @EXPORT);
+  $VERSION = "1.16";
+  @ISA = qw(Exporter);
+  @EXPORT = qw();
+ }
+
 sub new
 { 
  my $proto = shift;
